==> nextcloud-app-tasks-0.13.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/he.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "חשוב",
    "Today" : "היום",
    "Week" : "שבוע",
    "All" : "הכול",
    "Current" : "נוכחי",
    "Completed" : "הושלם",
    "Tasks" : "משימות",
    "The Tasks app for Nextcloud" : "יישומון המשימות ל־Nextcloud",
    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
    "No users or groups" : "אין משתמשים או קבוצות",
    "can edit" : "יש הרשאת עריכה",
    "Unshare with {displayName}" : "ביטול שיתוף עם {displayName}",
    "Unable to delete the share." : "לא ניתן למחוק את השיתוף.",
    "Unable to change permissions." : "לא ניתן לשנות הרשאות.",
    "New List" : "רשימה חדשה",
    "Cancel" : "ביטול",
    "Save" : "שמירה",
    "An empty name is not allowed." : "שדה שם ריק אינו מותר.",
    "Edit" : "עריכה",
    "Copy private link" : "העתקת קישור פרטי",
    "Copied" : "הועתק",
    "Can not copy" : "לא ניתן להעתיק",
    "Download" : "הורדה",
    "Delete" : "מחיקה",
    "Unshare" : "ביטול שיתוף",
    "Calendar link copied to clipboard." : "הקישור ללוח השנה הועתק ללוח הגזירים.",
    "Calendar link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור ללוח השנה אל לוח הגזירים.",
    "Default list" : "רשימת בררת מחדל",
    "Visibility of Smart Collections" : "הצגה של אוספים חכמים",
    "Hidden" : "מוסתר",
    "Visible" : "גלוי",
    "Automatic" : "אוטומטי",
    "No errors" : "אין שגיאות",
    "Open your browser console for more details" : "נא לפתוח את המסוף של הדפדפן שלך לקבלת פרטים נוספים",
    "Load all completed tasks." : "טעינת כל המשימות שהושלמו.",
    "Change sort order" : "שינוי סדר מיון",
    "Start date" : "תאריך התחלה",
    "Sort by start date and summary." : "מיון לפי תאריך התחלה ותקציר.",
    "Due date" : "תאריך יעד",
    "Sort by due date and summary." : "מיון לפי תאריך תפוגה ותקציר.",
    "Created date" : "תאריך יצירה",
    "Sort by created date and summary." : "מיון לפי תאריך יצירה ותקציר.",
    "Last modified" : "מועד שינוי אחרון",
    "Sort by last-modified date and summary." : "מיון לפי מועד שינוי אחרון ותקציר.",
    "Completed date" : "תאריך השלמה",
    "Sort by completed date." : "מיון לפי תאריך השלמה.",
    "Priority" : "עדיפות",
    "Sort by priority and summary." : "מיון לפי עדיפות ותקציר.",
    "Alphabetically" : "בסדר האלף-בית",
    "Sort by summary and priority." : "מיון לפי תקציר ועדיפות.",
    "Manually" : "באופן ידני",
    "Sort by manual order." : "מיון ידני.",
    "Task is completed" : "המשימה הושלמה",
    "{complete} % completed" : "{complete} % הושלמו",
    "[Yesterday]" : "[אתמול]",
    "[Today]" : "[היום]",
    "[Tomorrow]" : "[מחר]",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n פעילות מושלמת","%n פעילויות הושלמו","%n פעילויות הושלמו","%n פעילויות הושלמו"],
    "Tomorrow" : "מחר",
    "Set start date" : "קביעת תאריך התחלה",
    "Set start time" : "הגדרת זמן התחלה",
    "Set due date" : "הגדרת תאריך יעד",
    "Set due time" : "הגדרת מועד יעד",
    "All day" : "כל היום",
    "Select a calendar" : "הגדרת יומן",
    "Select categories" : "בחירת קטגוריות",
    "Add this as a new category" : "הוספת הקטגוריה הזאת כחדשה",
    "Task not found!" : "לא אותרה משימה!",
    "When shared show full event" : "כאשר משותף מציג אירוע מלא",
    "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
    "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
    "Canceled" : "מבוטלת",
    "[Starts today]" : "[מתחילה היום]",
    "[Starts tomorrow]" : "[מתחילה מחר]",
    "[Starts on] LL" : "[מתחילה במועד] LL",
    "[Started yesterday]" : "[החלה אתמול]",
    "[Started on] LL" : "[החלה במועד] LL",
    "[Started today at] LT" : "[החלה היום בשעה] LT",
    "[Starts today at] LT" : "[מתחילה היום בשעה] LT",
    "[Starts tomorrow at] LT" : "[מתחילה מחר בשעה] LT",
    "[Starts on] LL [at] LT" : "[מתחילה ביום] LL [בשעה] LT",
    "[Started yesterday at] LT" : "[החלה אתמול בשעה] LT",
    "[Started on] LL [at] LT" : "[החלה ביום] LL [בשעה] LT",
    "[Due today]" : "[מועד התפוגה הוא היום]",
    "[Due tomorrow]" : "[מועד התפוגה הוא מחר]",
    "[Due on] LL" : "[מועד התפוגה הוא] LL",
    "[Was due yesterday]" : "[מועד התפוגה היה אתמול]",
    "[Was due on] LL" : "[מועד התפוגה היה] LL",
    "[Was due today at] LT" : "[מועד התפוגה היה היום בשעה] LT",
    "[Due today at] LT" : "[מועד התפוגה הוא היום בשעה] LT",
    "[Due tomorrow at] LT" : "[מועד התפוגה הוא מחר בשעה] LT",
    "[Due on] LL [at] LT" : "[מועד התפוגה הוא] LL [בשעה] LT",
    "[Was due yesterday at] LT" : "[מועד התפוגה היה אתמול בשעה] LT",
    "[Was due on] LL [at] LT" : "[מועד התפוגה היה] LL [בשעה] LT",
    "No priority assigned" : "לא הוגדרה עדיפות",
    "Could not delete the task." : "לא ניתן למחוק את המשימה.",
    "Synchronizing to the server." : "מתבצע סנכרון מול השרת.",
    "Task successfully saved to server." : "המשימה נשמרה לשרת בהצלחה.",
    "Could not update the task." : "לא ניתן לעדכן את המשימה.",
    "An error occurred" : "אירעה שגיאה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-app-tasks-0.13.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/he.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "חשוב",
    "Today" : "היום",
    "Week" : "שבוע",
    "All" : "הכול",
    "Current" : "נוכחי",
    "Completed" : "הושלם",
    "Tasks" : "משימות",
    "The Tasks app for Nextcloud" : "יישומון המשימות ל־Nextcloud",
    "Add List…" : "הוספת רשימה…",
    "New List" : "רשימה חדשה",
    "Cancel" : "ביטול",
    "Save" : "שמירה",
    "The name \"{calendar}\" is already used." : "השם „{calendar}” כבר נמצא בשימוש.",
    "An empty name is not allowed." : "שדה שם ריק אינו מותר.",
    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
    "No users or groups" : "אין משתמשים או קבוצות",
    "can edit" : "יש הרשאת עריכה",
    "Unshare with {displayName}" : "ביטול שיתוף עם {displayName}",
    "Unable to delete the share." : "לא ניתן למחוק את השיתוף.",
    "Unable to change permissions." : "לא ניתן לשנות הרשאות.",
    "Edit" : "עריכה",
    "Copy private link" : "העתקת קישור פרטי",
    "Copied" : "הועתק",
    "Can not copy" : "לא ניתן להעתיק",
    "Download" : "הורדה",
    "Delete" : "מחיקה",
    "Unshare" : "ביטול שיתוף",
    "Calendar link copied to clipboard." : "הקישור ללוח השנה הועתק ללוח הגזירים.",
    "Calendar link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור ללוח השנה אל לוח הגזירים.",
    "Default list" : "רשימת בררת מחדל",
    "Visibility of Smart Collections" : "הצגה של אוספים חכמים",
    "Hidden" : "מוסתר",
    "Visible" : "גלוי",
    "Automatic" : "אוטומטי",
    "No errors" : "אין שגיאות",
    "Open your browser console for more details" : "נא לפתוח את המסוף של הדפדפן שלך לקבלת פרטים נוספים",
    "Load all completed tasks." : "טעינת כל המשימות שהושלמו.",
    "Change sort order" : "שינוי סדר מיון",
    "Start date" : "תאריך התחלה",
    "Sort by start date and summary." : "מיון לפי תאריך התחלה ותקציר.",
    "Due date" : "תאריך יעד",
    "Sort by due date and summary." : "מיון לפי תאריך תפוגה ותקציר.",
    "Created date" : "תאריך יצירה",
    "Sort by created date and summary." : "מיון לפי תאריך יצירה ותקציר.",
    "Last modified" : "מועד שינוי אחרון",
    "Sort by last-modified date and summary." : "מיון לפי מועד שינוי אחרון ותקציר.",
    "Completed date" : "תאריך השלמה",
    "Sort by completed date." : "מיון לפי תאריך השלמה.",
    "Priority" : "עדיפות",
    "Sort by priority and summary." : "מיון לפי עדיפות ותקציר.",
    "Alphabetically" : "בסדר האלף-בית",
    "Sort by summary and priority." : "מיון לפי תקציר ועדיפות.",
    "Manually" : "באופן ידני",
    "Sort by manual order." : "מיון ידני.",
    "Task is completed" : "המשימה הושלמה",
    "{complete} % completed" : "{complete} % הושלמו",
    "[Yesterday]" : "[אתמול]",
    "[Today]" : "[היום]",
    "[Tomorrow]" : "[מחר]",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n פעילות מושלמת","%n פעילויות הושלמו","%n פעילויות הושלמו","%n פעילויות הושלמו"],
    "Tomorrow" : "מחר",
    "Set start date" : "קביעת תאריך התחלה",
    "Set start time" : "הגדרת זמן התחלה",
    "Set due date" : "הגדרת תאריך יעד",
    "Set due time" : "הגדרת מועד יעד",
    "All day" : "כל היום",
    "Select a calendar" : "הגדרת יומן",
    "Select categories" : "בחירת קטגוריות",
    "Add this as a new category" : "הוספת הקטגוריה הזאת כחדשה",
    "Task not found!" : "לא אותרה משימה!",
    "When shared show full event" : "כאשר משותף מציג אירוע מלא",
    "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
    "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
    "Canceled" : "מבוטלת",
    "[Starts today]" : "[מתחילה היום]",
    "[Starts tomorrow]" : "[מתחילה מחר]",
    "[Starts on] LL" : "[מתחילה במועד] LL",
    "[Started yesterday]" : "[החלה אתמול]",
    "[Started on] LL" : "[החלה במועד] LL",
    "[Started today at] LT" : "[החלה היום בשעה] LT",
    "[Starts today at] LT" : "[מתחילה היום בשעה] LT",
    "[Starts tomorrow at] LT" : "[מתחילה מחר בשעה] LT",
    "[Starts on] LL [at] LT" : "[מתחילה ביום] LL [בשעה] LT",
    "[Started yesterday at] LT" : "[החלה אתמול בשעה] LT",
    "[Started on] LL [at] LT" : "[החלה ביום] LL [בשעה] LT",
    "[Due today]" : "[מועד התפוגה הוא היום]",
    "[Due tomorrow]" : "[מועד התפוגה הוא מחר]",
    "[Due on] LL" : "[מועד התפוגה הוא] LL",
    "[Was due yesterday]" : "[מועד התפוגה היה אתמול]",
    "[Was due on] LL" : "[מועד התפוגה היה] LL",
    "[Was due today at] LT" : "[מועד התפוגה היה היום בשעה] LT",
    "[Due today at] LT" : "[מועד התפוגה הוא היום בשעה] LT",
    "[Due tomorrow at] LT" : "[מועד התפוגה הוא מחר בשעה] LT",
    "[Due on] LL [at] LT" : "[מועד התפוגה הוא] LL [בשעה] LT",
    "[Was due yesterday at] LT" : "[מועד התפוגה היה אתמול בשעה] LT",
    "[Was due on] LL [at] LT" : "[מועד התפוגה היה] LL [בשעה] LT",
    "No priority assigned" : "לא הוגדרה עדיפות",
    "Could not delete the task." : "לא ניתן למחוק את המשימה.",
    "Synchronizing to the server." : "מתבצע סנכרון מול השרת.",
    "Task successfully saved to server." : "המשימה נשמרה לשרת בהצלחה.",
    "Could not update the task." : "לא ניתן לעדכן את המשימה.",
    "An error occurred" : "אירעה שגיאה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
